@@ -1,7 +1,7 @@
 use crate::async_token::NetxToken;
 use crate::result::RetResult;
 use anyhow::*;
-use data_rw::Data;
+use data_rw::DataOwnedReader;
 use std::collections::HashMap;
 use std::sync::Arc;
 
@@ -12,7 +12,7 @@ pub trait IController: Send + Sync {
 #[async_trait::async_trait]
 pub trait FunctionInfo: Send + Sync {
     fn function_type(&self) -> u8;
-    async fn call(&self, data: Data) -> Result<RetResult>;
+    async fn call(&self, data: DataOwnedReader) -> Result<RetResult>;
 }
 
 pub trait ICreateController {
